==> jc-1.4.0.tar.gz: java/security/DigestInputStream.h <==
// public class java.security.DigestInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ba33fa099fc2d5a4 java_security_DigestInputStream

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_java_security_DigestInputStream_H_
#define _JC_java_security_DigestInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_MessageDigest$object;

// Typedefs
typedef struct _jc_java_security_DigestInputStream$sub_refs	_jc_java_security_DigestInputStream$sub_refs;
typedef struct _jc_java_security_DigestInputStream$sub_nonrefs	_jc_java_security_DigestInputStream$sub_nonrefs;
typedef struct _jc_java_security_DigestInputStream$refs	_jc_java_security_DigestInputStream$refs;
typedef struct _jc_java_security_DigestInputStream$nonrefs	_jc_java_security_DigestInputStream$nonrefs;
typedef struct _jc_java_security_DigestInputStream$object	_jc_java_security_DigestInputStream$object;

typedef const struct _jc_java_security_DigestInputStream$vmethods	_jc_java_security_DigestInputStream$vmethods;
typedef const struct _jc_java_security_DigestInputStream$vtable	_jc_java_security_DigestInputStream$vtable;
typedef const struct _jc_java_security_DigestInputStream$vtype	_jc_java_security_DigestInputStream$vtype;

// Constructors
extern void _jc_java_security_DigestInputStream$method$_init$70c23e05fa718320(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_security_MessageDigest$object *);

// Virtual methods
extern struct _jc_java_security_MessageDigest$object *_jc_java_security_DigestInputStream$method$getMessageDigest$3b124d9f21254d6c(_jc_env *, struct _jc_java_security_DigestInputStream$object *);
extern void _jc_java_security_DigestInputStream$method$on$96b054f744a6b4c3(_jc_env *, struct _jc_java_security_DigestInputStream$object *, jboolean);
extern jint _jc_java_security_DigestInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_security_DigestInputStream$object *);
extern jint _jc_java_security_DigestInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_security_DigestInputStream$method$setMessageDigest$ea52511d9ace745c(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_java_security_MessageDigest$object *);
extern void _jc_java_security_DigestInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_DigestInputStream$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_DigestInputStream$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_DigestInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_DigestInputStream$method_info$getMessageDigest$3b124d9f21254d6c;
extern _jc_method _jc_java_security_DigestInputStream$method_info$on$96b054f744a6b4c3;
extern _jc_method _jc_java_security_DigestInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_security_DigestInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_security_DigestInputStream$method_info$setMessageDigest$ea52511d9ace745c;
extern _jc_method _jc_java_security_DigestInputStream$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_security_DigestInputStream$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_DigestInputStream$vmethods {
	struct _jc_java_security_MessageDigest$object	*(*getMessageDigest$3b124d9f21254d6c)(_jc_env *, struct _jc_java_security_DigestInputStream$object *);
	void	(*on$96b054f744a6b4c3)(_jc_env *, struct _jc_java_security_DigestInputStream$object *, jboolean);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_security_DigestInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*setMessageDigest$ea52511d9ace745c)(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_java_security_MessageDigest$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_DigestInputStream$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_DigestInputStream$object *);
};

// Vtable
struct _jc_java_security_DigestInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_security_DigestInputStream$vmethods	java_security_DigestInputStream;
};

// Vtype
struct _jc_java_security_DigestInputStream$vtype {
	_jc_type			type;
	_jc_java_security_DigestInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_DigestInputStream$sub_refs {
	struct _jc_java_security_MessageDigest$object	*digest;
};

// Reference instance fields (object)
struct _jc_java_security_DigestInputStream$refs {
    _jc_java_security_DigestInputStream$sub_refs	java_security_DigestInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_DigestInputStream$sub_nonrefs {
	jboolean	state;
};

// Non-reference instance fields (object)
struct _jc_java_security_DigestInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_security_DigestInputStream$sub_nonrefs	java_security_DigestInputStream;
};

// Object instance structure
struct _jc_java_security_DigestInputStream$object {
	_jc_java_security_DigestInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_DigestInputStream$vtype	*vtype;
	_jc_java_security_DigestInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_DigestInputStream$vtype _jc_java_security_DigestInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_DigestInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_DigestInputStream$class_object;

#endif	/* _JC_java_security_DigestInputStream_H_ */

==> jc-1.4.6.tar.gz: java/security/DigestInputStream.h <==
// public class java.security.DigestInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ba33fa099fc2d5a4 java_security_DigestInputStream

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_java_security_DigestInputStream_H_
#define _JC_java_security_DigestInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_MessageDigest$object;

// Typedefs
typedef struct _jc_java_security_DigestInputStream$sub_refs	_jc_java_security_DigestInputStream$sub_refs;
typedef struct _jc_java_security_DigestInputStream$sub_nonrefs	_jc_java_security_DigestInputStream$sub_nonrefs;
typedef struct _jc_java_security_DigestInputStream$refs	_jc_java_security_DigestInputStream$refs;
typedef struct _jc_java_security_DigestInputStream$nonrefs	_jc_java_security_DigestInputStream$nonrefs;
typedef struct _jc_java_security_DigestInputStream$object	_jc_java_security_DigestInputStream$object;

typedef const struct _jc_java_security_DigestInputStream$vmethods	_jc_java_security_DigestInputStream$vmethods;
typedef const struct _jc_java_security_DigestInputStream$vtable	_jc_java_security_DigestInputStream$vtable;
typedef const struct _jc_java_security_DigestInputStream$vtype	_jc_java_security_DigestInputStream$vtype;

// Constructors
extern void _jc_java_security_DigestInputStream$method$_init$70c23e05fa718320(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_security_MessageDigest$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_MessageDigest$object *_jc_java_security_DigestInputStream$method$getMessageDigest$3b124d9f21254d6c(_jc_env *, struct _jc_java_security_DigestInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DigestInputStream$method$on$96b054f744a6b4c3(_jc_env *, struct _jc_java_security_DigestInputStream$object *, jboolean) _JC_JCNI_ATTR;
extern jint _jc_java_security_DigestInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_security_DigestInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_DigestInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_security_DigestInputStream$method$setMessageDigest$ea52511d9ace745c(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_java_security_MessageDigest$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DigestInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_DigestInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_DigestInputStream$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_DigestInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_DigestInputStream$method_info$getMessageDigest$3b124d9f21254d6c;
extern _jc_method _jc_java_security_DigestInputStream$method_info$on$96b054f744a6b4c3;
extern _jc_method _jc_java_security_DigestInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_security_DigestInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_security_DigestInputStream$method_info$setMessageDigest$ea52511d9ace745c;
extern _jc_method _jc_java_security_DigestInputStream$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_security_DigestInputStream$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_DigestInputStream$vmethods {
	struct _jc_java_security_MessageDigest$object	*(*getMessageDigest$3b124d9f21254d6c)(_jc_env *, struct _jc_java_security_DigestInputStream$object *) _JC_JCNI_ATTR;
	void	(*on$96b054f744a6b4c3)(_jc_env *, struct _jc_java_security_DigestInputStream$object *, jboolean) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_security_DigestInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*setMessageDigest$ea52511d9ace745c)(_jc_env *, struct _jc_java_security_DigestInputStream$object *, struct _jc_java_security_MessageDigest$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_DigestInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_DigestInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_DigestInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_security_DigestInputStream$vmethods	java_security_DigestInputStream;
};

// Vtype
struct _jc_java_security_DigestInputStream$vtype {
	_jc_type			type;
	_jc_java_security_DigestInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_DigestInputStream$sub_refs {
	struct _jc_java_security_MessageDigest$object	*digest;
};

// Reference instance fields (object)
struct _jc_java_security_DigestInputStream$refs {
    _jc_java_security_DigestInputStream$sub_refs	java_security_DigestInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_DigestInputStream$sub_nonrefs {
	jboolean	state;
};

// Non-reference instance fields (object)
struct _jc_java_security_DigestInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_security_DigestInputStream$sub_nonrefs	java_security_DigestInputStream;
};

// Object instance structure
struct _jc_java_security_DigestInputStream$object {
	_jc_java_security_DigestInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_DigestInputStream$vtype	*vtype;
	_jc_java_security_DigestInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_DigestInputStream$vtype _jc_java_security_DigestInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_DigestInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_DigestInputStream$class_object;

#endif	/* _JC_java_security_DigestInputStream_H_ */
